@@ -1,9 +1,9 @@
-# $Id: auth.rb 461 2009-06-29 09:44:44Z helixblue $
+# $Id: auth.rb 527 2010-01-24 19:26:12Z helixblue $
 
 
 module Auth
   include Common
-  include Display 
+  include Messages 
   @@login_url = 'http://www.geocaching.com/login/'
   
   def login(user, password)
@@ -58,10 +58,10 @@ module Auth
       when /You are logged in as/
         debug "Found login confirmation!"
         return true
-      when /^\<input type=\"hidden\" name=\"(.*?)\".*value=\"(.*?)\"/
-        debug "found hidden post variable: #{$1}"
+      when /^\<input type=\"hidden\" name=\"(.*?)\".id=\".*?\" value=\"(.*?)\"/
+        debug "found hidden post variable: #{$1} = #{$2}"
         @postVars[$1]=$2
-      when /\<form name=\"aspnetForm\" method=\"post\" action=\"(.*?)\"/
+      when /\<form name=\"aspnetForm\" method=\"post\" action=\"(.*aspx)\" id/
         @postURL='http://www.geocaching.com/login/' + $1
         @postURL.gsub!('&amp;', '&')
         debug "post URL is #{@postURL}"
