@@ -1,4 +1,4 @@
-# $Id: details.rb 577 2010-04-11 15:39:20Z helixblue $
+# $Id: details.rb 593 2010-05-05 05:22:02Z helixblue $
 require 'lib/bishop'
 require 'time'
 
@@ -11,8 +11,8 @@ class CacheDetails
 
   # This now uses the printable version of the cache data. For now, we get the last 10
   # logs to a cache.
-  @@baseURL="http://www.geocaching.com/seek/cache_details.aspx?pf=y&log=y&numlogs=5&decrypt="
-
+ 
+ @@baseURL="http://www.geocaching.com/seek/cache_details.aspx?log=y&decrypt=&numlogs=5"
   def initialize(data)
     @waypointHash = data
     @useShadow=1
@@ -122,12 +122,12 @@ class CacheDetails
       return 3.0
     end
 
-    score=total / comments
+    score=total.to_f / comments.to_f
 
     # a grade of >28 is considered awesome
     # a grade of <-20 is considered pretty bad
-    debug "total=#{total} comments=#{comments} score=#{score}"
-    grade=((score + 25) / 5.3).round.to_f / 2
+    debug "fun total=#{total} comments=#{comments} score=#{score}"
+    grade=((score + 25) / 5.3).round.to_f / 2.0
     if grade > 5.0
       grade=5.0
     elsif grade < 0.0
@@ -158,6 +158,8 @@ class CacheDetails
         @waypointHash[wid]['shortdesc'] = ''
         @waypointHash[wid]['longdesc'] = ''
         @waypointHash[wid]['details'] = ''
+        @waypointHash[wid]['archived'] = 'False'
+        @waypointHash[wid]['available'] = 'True'		  
 
         if not @waypointHash[wid]['mtime']
           @waypointHash[wid]['mdays'] = -1
@@ -177,20 +179,37 @@ class CacheDetails
         debug "found creator id: #{@waypointHash[wid]['creator_id']}"
       end
 
+	  #by <a href="http://www.geocaching.com/profile/?guid=96ef640d-c84b-4cbb-af31-9272d14cc26d&wid=8e4f945c-cb14-4bd3-8f25-8e7974e68259&ds=2">Rain734</a>
+      if line =~ /^\s+by \<a .*?guid=([\w-]+).*?>(.*?)\<\/a/
+        @waypointHash[wid]['creator_id'] = $1
+        @waypointHash[wid]['creator'] = $2
+        debug "found creator id: #{@waypointHash[wid]['creator_id']}"
+      end
+
+	  
+	  
       # <strong>Difficulty:</strong> <span id="ctl00_ContentBody_Difficulty"><img src="http://www.geocaching.com/images/stars/stars2.gif" alt="2 out of 5" />
       if line =~ /Difficulty:.*?([-\d\.]+) out of 5/
-        debug "difficulty: #{$1}"
-        @waypointHash[wid]['difficulty']=$1.to_f
+        if $1.to_f == $1.to_i
+          @waypointHash[wid]['difficulty']=$1.to_i
+        else
+          @waypointHash[wid]['difficulty']=$1.to_f
+        end
+        debug "difficulty: #{@waypointHash[wid]['difficulty']}"
       end
 
       # strong>Terrain:</strong> <span id="ctl00_ContentBody_Terrain"><img src="http://www.geocaching.com/images/stars/stars2.gif" alt="2 out of 5" />
       if line =~ /Terrain:.*?([-\d\.]+) out of 5/
-        debug "terrain: #{$1}"
-        @waypointHash[wid]['terrain']=$1.to_f
+        if $1.to_f == $1.to_i
+          @waypointHash[wid]['terrain']=$1.to_i
+        else
+          @waypointHash[wid]['terrain']=$1.to_f
+        end
+        debug "terrain: #{@waypointHash[wid]['terrain']}"
       end
 
       # DateHidden">2/22/2009</span>
-      if line =~ /DateHidden\">([\w\/]+)\</
+      if line =~ /Hidden\s+:\<\/strong\>\s+([\w\/]+)/
         if $1 != 'N/A'
           @waypointHash[wid]['ctime'] = parseDate($1)
           @waypointHash[wid]['cdays'] = daysAgo(@waypointHash[wid]['ctime'])
@@ -198,7 +217,7 @@ class CacheDetails
         end
       end
 
-      if line =~ /with an account to view/
+      if line =~ /with a Geocaching.com account to view the specific location/
         displayWarning "Oops, we are not actually logged in!"
         return 'login-required'
       end
@@ -210,11 +229,11 @@ class CacheDetails
       end
 
       # href="/wpt/?lat=35.933717&amp;lon=-78.487483&amp;detail=1"
-      if line =~ /\?lat=([\d\.-]+)\&lon=([\d\.-]+)/
-        @waypointHash[wid]['latdata'] = $1
-        @waypointHash[wid]['londata'] = $2
-        debug "got digital lat/lon: #{$1} #{$2}"
-      end
+    #  if line =~ /\?lat=([\d\.-]+)\&lon=([\d\.-]+)/
+    #    @waypointHash[wid]['latdata'] = $1
+    #    @waypointHash[wid]['londata'] = $2
+    #    debug "got digital lat/lon: #{$1} #{$2}"
+    #  end
 
 
       # span id="ctl00_ContentBody_Location">In North Carolina, United States <small>
@@ -229,8 +248,20 @@ class CacheDetails
         debug "found country: #{$1}"
       end
 
+	  #Archived
+	  if line =~ /This cache has been archived, but is available/
+	    @waypointHash[wid]['archived'] = 'True'
+	  end
+	  
+	  #Disabled
+	  if line =~ /This cache is temporarily unavailable. Read the logs below/
+	    @waypointHash[wid]['available'] = 'False'
+	  end
+	  
       # latitude and longitude in the written form. Rewritten by Scott Brynen for Southpole compatibility.
-      if line =~ /LatLon\".*\>.*?([NWSE]) (\d+).*? ([\d\.]+) ([NWSE]) (\d+).*? ([\d\.]+)\</
+	  #<span id="ctl00_ContentBody_LatLon" style="font-weight:bold;">N 37┬░ 12.882 W 121┬░ 30.744</span>&nbsp;
+	  #note: the degree sign can be stored as more than one character, hence the "\D+" -- svw
+      if line =~ /([NS])\s+(\d+)\D+([\d\.]+)\s+([EW])\s+(\d+)\D+([\d\.]+)\</
         @waypointHash[wid]['latwritten'] = $1 + $2 + ' ' + $3
         @waypointHash[wid]['lonwritten'] = $4 + $5 + ' ' + $6
         @waypointHash[wid]['latdata'] = ($2.to_f + $3.to_f / 60) * ($1 == 'S' ? -1:1)
@@ -247,14 +278,15 @@ class CacheDetails
         if (wid)
           @waypointHash[wid]['warning'] = warning.dup
         end
-        if warning =~ /Premium Member/
-          debug "This cache appears to be available to premium members only."
-          return 'subscriber-only'
-        end
-      end
+     end
 
-      if line =~ /CacheLogs\"\>/
-        debug "inspecting comments: #{line}"
+      if line =~ /Sorry, the owner of this listing has made it viewable to Premium Members only/
+        debug "This cache appears to be available to premium members only."
+        return 'subscriber-only'
+     end
+
+      if line =~ /LogsTable Table\"\>/
+        #debug "inspecting comments: #{line}"
         cnum = 0
         funTotal = 0.0
         fnum = 0
@@ -278,6 +310,11 @@ class CacheDetails
             @waypointHash[wid]['visitors'].push(name.downcase)
           when 'sad'
             type = 'Didn\'t find it'
+	      when 'greenlight'
+	        type = 'Published'
+	      when 'redlight'
+	        type = 'Retracted'
+            nograde=1
           when 'note'
             type = 'Note'
           when 'remove'
@@ -288,10 +325,24 @@ class CacheDetails
           when 'disabled'
             type = 'Cache Disabled!'
             nograde=1
+	      when 'enabled'
+	     	type = 'Cache Enabled'
+	    	nograde=1
+	      when 'maint'
+	        type = 'Cache Maintained'
+	     	nograde=1
+	      when 'needsmaint'
+	        type = 'Needs Maintaince'
+            nograde=1
           else
             type = 'Other'
             nograde=1
           end
+          
+          if @waypointHash[wid]['creator'] == name
+            debug "not grading comment by owner: #{name}"
+            nograde=1
+          end
 
           debug "comment [#{cnum}] is '#{type}' by #{name}[#{user_id}] on #{date}: #{comment}"
           comment.gsub!(/\<.*?\>/, ' ')
