@@ -1,4 +1,4 @@
-# $Id: output.rb 577 2010-04-11 15:39:20Z helixblue $
+# $Id: output.rb 593 2010-05-05 05:22:02Z helixblue $
 require 'cgi'
 require 'lib/templates'
 
@@ -414,8 +414,10 @@ class Output
           symbols[wid] =  symbols[wid] + "<b><font color=\"#999922\">&sect;</font></b>"
         end
 
-        if (@wpHash[wid]['funfactor'] >= 3.5)
+        if (@wpHash[wid]['funfactor'] >= 3.0)
           symbols[wid] =  symbols[wid] + "<b><font color=\"#BB2222\">&hearts;</font></b>"
+        elsif (@wpHash[wid]['funfactor'] >= 2.1)
+          symbols[wid] =  symbols[wid] + "<b><font color=\"#BB9999\">&hearts;</font></b>"
         end
 
         if (@wpHash[wid]['difficulty'] > 3)
