@@ -1,4 +1,4 @@
-# $Id: search.rb 577 2010-04-11 15:39:20Z helixblue $
+# $Id: search.rb 591 2010-05-02 13:06:44Z helixblue $
 
 require 'cgi'
 require 'geocode'
@@ -285,7 +285,7 @@ class SearchCache
 
       #<IMG src="./gc_files/8.gif" alt="Unknown Cache" width="32" height="32"></A>
       # <IMG src="./gc_files/21.gif" alt="Travel Bug Dog Tag (1 item)">  </TD>
-      when /WptTypes\/[\w].*?alt=\"(.*?)\"/
+      when /WptTypes\/[\d].*?alt=\"(.*?)\"/
         # This line also has travel bug data
         full_type = $1
         if line =~ /Travel Bug.*?\((.*?)\)/ 
@@ -309,8 +309,18 @@ class SearchCache
       # (2/1)<br />
       # (1/1.5)<br />
       when /\(([-\d\.]+)\/([-\d\.]+)\)\<br/
-        cache['difficulty']=$1.to_f
-        cache['terrain']=$2.to_f
+        # Use integers when we can
+        if $1.to_f == $1.to_i
+          cache['difficulty']=$1.to_i
+        else
+          cache['difficulty']=$1.to_f
+        end 
+
+        if $1.to_f == $1.to_i
+          cache['terrain']=$2.to_i
+        else
+          cache['terrain']=$2.to_f
+        end
         debug "difficulty=#{cache['difficulty']} terr=#{cache['terrain']}"
         
       # <img src="/images/icons/container/micro.gif" alt="Size: Micro" />
@@ -320,14 +330,14 @@ class SearchCache
 
       # <td>Yesterday<strong>*</strong><br /><span class="Success"></span></td> 
       # <td>15 Jan 10<br /><span class="Success"></span></td>
-      when /^ +(\w+[ \w]+)\**\<[bs][rt]/
+      when /\<td\>\s+(\w+[ \w]+)\**\<[bs][rt]/
         debug "last found date: #{$1} at line: #{line}"
         cache['mtime'] = parseDate($1)
         cache['mdays'] = daysAgo(cache['mtime'])
         debug "mtime=#{cache['mtime']} mdays=#{cache['mdays']}"
         
-      # 21 May 09
-      when /^ +(\d+ \w{3} \d+).*/
+      # <td>17 Mar 08</td>
+      when /^\s+(\d+[ \w]+)\s*$/
         cache['ctime'] = parseDate($1)
         cache['cdays'] = daysAgo(cache['ctime'])
         debug "ctime=#{cache['ctime']} cdays=#{cache['cdays']}"
@@ -344,12 +354,12 @@ class SearchCache
         name = $2
         debug "Found cache details link for #{name}"
 
-        if name =~ /class=\"Warning/
+        if name =~ /class=\"OldWarning/
           cache['archived']=1
           debug "#{name} appears to be archived"
         end
 
-        if name =~ /Strike"\>(.*?)\<\//
+        if name =~ /\"Strike"\>(.*?)\<\//
           cache['disabled']=1
           debug "#{name} appears to be disabled"
           name=$1
@@ -358,7 +368,7 @@ class SearchCache
         end
 
         cache['name']=name.gsub(/ +$/, '')
-        debug "sid=#{cache['sid']} name=#{cache['name']} (disabled=#{cache['disabled']})"
+        debug "sid=#{cache['sid']} name=#{cache['name']} (disabled=#{cache['disabled']}) (archived=#{cache['archived']})"
 
       # by gonsuke@Zerosen and Bakatono@Zerosen
       when /^ +by (.*?)$/
