@@ -1,7 +1,7 @@
 # This is our dump templating engine. It only handles really simple text formats at the moment.
 # GeoToad 4.0 will have a plugins architecture that replaces this.
 #
-# $Id: templates.rb 575 2010-04-11 14:43:11Z helixblue $
+# $Id: templates.rb 594 2010-05-26 09:29:01Z helixblue $
 
 $Format = {
   'gpspoint'    => {
@@ -47,11 +47,11 @@ $Format = {
       "  <name><%outEntity.id%></name>\r\n" +
       "  <desc><%wpEntity.name%> by <%wpEntity.creator%>, <%wp.type%> (<%wp.difficulty%>/<%wp.terrain%>)</desc>\r\n" +
       "  <url><%out.url%></url>\r\n" +
-      "  <urlname><%wpEntity.name%> by <%wpEntity.creator%>, <%wp.fulltype%> (<%wp.difficulty%>/<%wp.terrain%>)</urlname>\r\n" +
-      "  <sym>Geocache</sym><type>Geocache</type>\r\n" +
-      "  <groundspeak:cache id=\"<%wp.sid%>\" available=\"True\" archived=\"False\" xmlns:groundspeak=\"http://www.groundspeak.com/cache/1/0\">\r\n" +
+      "  <urlname><%wpEntity.name%></urlname>\r\n" +
+      "  <sym>Geocache</sym>\r\n" + 
+      "  <type>Geocache|<%wp.fulltype%></type>\r\n" +
+      "  <groundspeak:cache id=\"<%wp.sid%>\" available=\"<%wpEntity.available%>\" archived=\"<%wpEntity.archived%>\" xmlns:groundspeak=\"http://www.groundspeak.com/cache/1/0\">\r\n" +
       "  <groundspeak:name><%wpEntity.name%></groundspeak:name>\r\n" +
-      " <groundspeak:full_name><%wpEntity.name%></groundspeak:full_name>\r\n"+
       "  <groundspeak:placed_by><%wpEntity.creator%></groundspeak:placed_by>\r\n" +
       "  <groundspeak:owner id=\"<%wpEntity.creator_id%>\"><%wpEntity.creator%></groundspeak:owner>\r\n" +
       "  <groundspeak:type><%wp.fulltype%></groundspeak:type>\r\n" +
@@ -85,8 +85,9 @@ $Format = {
       "<b><font color=\"#11CC11\">&euro;</font></b> have travelbugs&nbsp;&nbsp;&nbsp;" +
       "<b><font color=\"#9900CC\">&infin;</font></b> never been found&nbsp;&nbsp;&nbsp;" +
       "<b><font color=\"#999922\">&sect;</font></b> terrain rating of 3.5+&nbsp;&nbsp;&nbsp;" +
-      "<b><font color=\"#440000\">&uarr;</font></b> difficulty rating of 3.5+&nbsp;&nbsp;&nbsp;" +
-      "<b><font color=\"#BB2222\">&hearts;</font></b> fun factor rating of 3.5+<br>" +
+      "<b><font color=\"#440000\">&uarr;</font></b> difficulty rating of 3.5+&nbsp;&nbsp;&nbsp;<br />" +
+      "<b><font color=\"#BB9999\">&hearts;</font></b> fun factor of 2.1+&nbsp;&nbsp;&nbsp;" +
+      "<b><font color=\"#BB2222\">&hearts;</font></b> fun factor of 3.0+<br>" +
       # Not yet ready for consumption
     #"<b><font color=\"#333333\">--</font></b> comments seem negative&nbsp;&nbsp;&nbsp;" +
     #"<b><font color=\"#000000\">++</font></b> comments seem very positive" +
